import { RelayerProperties } from '@tornado/sdk-data';
import { AxiosInstance } from 'axios';
import { BigNumber } from 'ethers';
import { Web3Provider, Networkish } from '@ethersproject/providers';
export declare namespace Options {
    interface Relayer {
        url: string;
        httpClient: AxiosInstance;
    }
}
export interface WithdrawalRequestResult {
    success: boolean;
    txHash?: string;
}
export type RelayerOptions = Options.Relayer;
export interface ObfuscationOptions {
    port?: number;
    headers?: {
        name: string;
        value: string;
    }[];
    rv?: string;
}
/**
 * You can also set up a SOCKS5 I2P tunnel on some port and then use that instead. Meaning that this should be compatible with I2P.
 */
export declare class TorProvider extends Web3Provider {
    constructor(url: string, torOpts?: ObfuscationOptions, network?: Networkish);
}
export declare const TorHttpClient: new (opts?: {
    port?: number;
    headers?: {
        [key: string]: string;
    };
    rv?: string;
}) => AxiosInstance;
export declare const RegularHttpClient: new (opts?: any) => AxiosInstance;
export declare class Relayer {
    url: string;
    httpClient: AxiosInstance;
    private _fetched;
    private _address?;
    private _version?;
    private _serviceFee?;
    private _miningFee?;
    private _status?;
    private _chainId?;
    private _prices?;
    constructor(options: Options.Relayer, properties?: RelayerProperties);
    /**
     * This function MUST be called to unlock the rest of the `Relayer` class functionality, as otherwise we don't have the property data necessary for all the logic we want.
     * @returns Fetched `RelayerProperties`.
     */
    fetchProperties(): Promise<RelayerProperties>;
    private _propertiesFetched;
    get address(): string;
    get version(): string;
    get serviceFeePercent(): number;
    get miningFeePercent(): number;
    get status(): string;
    get chainId(): number;
    get prices(): Map<string, BigNumber>;
    get properties(): RelayerProperties;
    getETHPurchasePrice(token: string): Promise<BigNumber>;
    handleWithdrawal(instanceAddress: string, proof: Array<string>): Promise<WithdrawalRequestResult>;
    private _handleHTTPError;
    /**
     * Construct a new Relayer by reading relayer data from cache.
     */
    static fromCache(options: Options.Relayer): Promise<Relayer>;
    /**
     * Cache relayer data into a PouchDB database in your cache folder. This will automatically fetch properties if they are not fetched.
     */
    remember(): Promise<void>;
}
//# sourceMappingURL=index.d.ts.map